abacusai.model_monitor_summary — AbacusAI documentation

# `abacusai.model_monitor_summary`

## Module Contents

### Classes

`ModelMonitorSummary` | A summary of model monitor

class abacusai.model_monitor_summary.ModelMonitorSummary(client, monitorAccuracy=None, modelDrift=None, dataIntegrity=None, biasViolations=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A summary of model monitor

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - monitorAccuracy (list) –

    - modelDrift (list) –

    - dataIntegrity (list) –

    - biasViolations (list) –

  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict